

set -ex



zopfli -h
zopflipng -h
test -f $PREFIX/lib/libzopfli${SHLIB_EXT}
test -f $PREFIX/lib/libzopflipng${SHLIB_EXT}
test -f $PREFIX/include/zopfli/zopfli.h
test -f $PREFIX/include/zopfli/zopflipng_lib.h
test -f $PREFIX/include/zopfli/zlib_container.h
test -f $PREFIX/include/zopfli/gzip_container.h
exit 0
